mtd/drivers/mtd/maps amd76xrom.c, 1.10, 1.11 arctic-mtd.c, 1.10, 1.11 autcpu12-nvram.c, 1.5, 1.6 beech-mtd.c, 1.7, 1.8 cdb89712.c, 1.7, 1.8 ceiva.c, 1.9, 1.10 cfi_flagadm.c, 1.11, 1.12 cstm_mips_ixx.c, 1.9, 1.10 db1550-flash.c, 1.1, 1.2 db1x00-flash.c, 1.1, 1.2 dbox2-flash.c, 1.10, 1.11 dc21285.c, 1.18, 1.19 dilnetpc.c, 1.12, 1.13 ebony.c, 1.9, 1.10 edb7312.c, 1.9, 1.10 elan-104nc.c, 1.19, 1.20 epxa10db-flash.c, 1.10, 1.11 fortunet.c, 1.6, 1.7 h720x-flash.c, 1.7, 1.8 ichxrom.c, 1.2, 1.3 impa7.c, 1.9, 1.10 integrator-flash.c, 1.15, 1.16 integrator-flash-v24.c, 1.12, 1.13 iq80310.c, 1.17, 1.18 ixp4xx.c, 1.1, 1.2 l440gx.c, 1.12, 1.13 lasat.c, 1.6, 1.7 lubbock-flash.c, 1.14, 1.15 mbx860.c, 1.5, 1.6 mpc1211.c, 1.1, 1.2 netsc520.c, 1.9, 1.10 nettel.c, 1.4, 1.5 ocelot.c, 1.12, 1.13 octagon-5066.c, 1.24, 1.25 omap-toto-flash.c, 1.1, 1.2 pb1550-flash.c, 1.2, 1.3 pb1xxx-flash.c, 1.10, 1.11 pci.c, 1.6, 1.7 pcmciamtd.c, 1.49, 1.50 pnc2000.c, 1.14, 1.15 redwood.c, 1.7, 1.8 rpxlite.c, 1.19, 1.20 sa1100-flash.c, 1.38, 1.39 sbc8240.c, 1.2, 1.3 sbc_gxx.c, 1.27, 1.28 sc520cdp.c, 1.15, 1.16 scb2_flash.c, 1.7, 1.8 scx200_docflash.c, 1.5, 1.6 solutionengine.c, 1.12, 1.13 sun_uflash.c, 1.8, 1.9 tqm8xxl.c, 1.10, 1.11 tsunami_flash.c, 1.6, 1.7 uclinux.c, 1.6, 1.7 vmax301.c, 1.28, 1.29 wr_sbc82xx_flash.c, 1.1, 1.2

David Woodhouse dwmw2 at infradead.org
Mon Jul 12 17:59:48 EDT 2004


Update of /home/cvs/mtd/drivers/mtd/maps
In directory phoenix.infradead.org:/tmp/cvs-serv26673

Modified Files:
	amd76xrom.c arctic-mtd.c autcpu12-nvram.c beech-mtd.c 
	cdb89712.c ceiva.c cfi_flagadm.c cstm_mips_ixx.c 
	db1550-flash.c db1x00-flash.c dbox2-flash.c dc21285.c 
	dilnetpc.c ebony.c edb7312.c elan-104nc.c epxa10db-flash.c 
	fortunet.c h720x-flash.c ichxrom.c impa7.c integrator-flash.c 
	integrator-flash-v24.c iq80310.c ixp4xx.c l440gx.c lasat.c 
	lubbock-flash.c mbx860.c mpc1211.c netsc520.c nettel.c 
	ocelot.c octagon-5066.c omap-toto-flash.c pb1550-flash.c 
	pb1xxx-flash.c pci.c pcmciamtd.c pnc2000.c redwood.c rpxlite.c 
	sa1100-flash.c sbc8240.c sbc_gxx.c sc520cdp.c scb2_flash.c 
	scx200_docflash.c solutionengine.c sun_uflash.c tqm8xxl.c 
	tsunami_flash.c uclinux.c vmax301.c wr_sbc82xx_flash.c 
Log Message:
s/buswidth/bankwidth/g

Index: amd76xrom.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/amd76xrom.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- amd76xrom.c	12 Jul 2004 14:26:14 -0000	1.10
+++ amd76xrom.c	12 Jul 2004 21:59:43 -0000	1.11
@@ -39,7 +39,7 @@
 	.map = {
 		.name = MOD_NAME,
 		.size = 0,
-		.buswidth = 1,
+		.bankwidth = 1,
 	}
 	/* remaining fields of structure are initialized to 0 */
 };

Index: arctic-mtd.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/arctic-mtd.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- arctic-mtd.c	2 Jun 2003 16:37:59 -0000	1.10
+++ arctic-mtd.c	12 Jul 2004 21:59:43 -0000	1.11
@@ -72,7 +72,7 @@
 static struct map_info arctic_mtd_map = {
 	.name		= NAME,
 	.size		= SIZE,
-	.buswidth	= BUSWIDTH,
+	.bankwidth	= BUSWIDTH,
 	.phys		= PADDR,
 };
 

Index: autcpu12-nvram.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/autcpu12-nvram.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- autcpu12-nvram.c	21 May 2003 12:45:18 -0000	1.5
+++ autcpu12-nvram.c	12 Jul 2004 21:59:43 -0000	1.6
@@ -39,7 +39,7 @@
 struct map_info autcpu12_sram_map = {
 	.name = "SRAM",
 	.size = 32768,
-	.buswidth = 4,
+	.bankwidth = 4,
 	.phys = 0x12000000,
 };
 

Index: beech-mtd.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/beech-mtd.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- beech-mtd.c	21 May 2003 12:45:18 -0000	1.7
+++ beech-mtd.c	12 Jul 2004 21:59:43 -0000	1.8
@@ -51,7 +51,7 @@
 static struct map_info beech_mtd_map = {
 	.name =		NAME,
 	.size =		SIZE,
-	.buswidth =	BUSWIDTH,
+	.bankwidth =	BUSWIDTH,
 	.phys =		PADDR
 };
 

Index: cdb89712.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/cdb89712.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- cdb89712.c	21 May 2003 12:45:18 -0000	1.7
+++ cdb89712.c	12 Jul 2004 21:59:43 -0000	1.8
@@ -23,7 +23,7 @@
 struct map_info cdb89712_flash_map = {
 	.name = "flash",
 	.size = FLASH_SIZE,
-	.buswidth = FLASH_WIDTH,
+	.bankwidth = FLASH_WIDTH,
 	.phys = FLASH_START,
 };
 
@@ -93,7 +93,7 @@
 struct map_info cdb89712_sram_map = {
 	.name = "SRAM",
 	.size = SRAM_SIZE,
-	.buswidth = SRAM_WIDTH,
+	.bankwidth = SRAM_WIDTH,
 	.phys = SRAM_START,
 };
 
@@ -161,7 +161,7 @@
 struct map_info cdb89712_bootrom_map = {
 	.name = "BootROM",
 	.size = BOOTROM_SIZE,
-	.buswidth = BOOTROM_WIDTH,
+	.bankwidth = BOOTROM_WIDTH,
 	.phys = BOOTROM_START,
 };
 

Index: ceiva.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/ceiva.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- ceiva.c	12 Jul 2004 14:26:56 -0000	1.9
+++ ceiva.c	12 Jul 2004 21:59:43 -0000	1.10
@@ -151,7 +151,7 @@
 		}
 
 		clps[i].map->virt = (unsigned long)clps[i].vbase;
-		clps[i].map->buswidth = clps[i].width;
+		clps[i].map->bankwidth = clps[i].width;
 		clps[i].map->size = clps[i].size;
 
 		simple_map_init(&clps[i].map);

Index: cfi_flagadm.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/cfi_flagadm.c,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- cfi_flagadm.c	21 May 2003 12:45:18 -0000	1.11
+++ cfi_flagadm.c	12 Jul 2004 21:59:43 -0000	1.12
@@ -60,7 +60,7 @@
 struct map_info flagadm_map = {
 		.name =		"FlagaDM flash device",
 		.size =		FLASH_SIZE,
-		.buswidth =	2,
+		.bankwidth =	2,
 };
 
 struct mtd_partition flagadm_parts[] = {

Index: cstm_mips_ixx.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/cstm_mips_ixx.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- cstm_mips_ixx.c	21 May 2003 12:45:18 -0000	1.9
+++ cstm_mips_ixx.c	12 Jul 2004 21:59:43 -0000	1.10
@@ -104,7 +104,7 @@
 	char *name;
 	unsigned long window_addr;
 	unsigned long window_size;
-	int buswidth;
+	int bankwidth;
 	int num_partitions;
 };
 
@@ -116,7 +116,7 @@
         "big flash",     // name
 	0x08000000,      // window_addr
 	0x02000000,      // window_size
-        4,               // buswidth
+        4,               // bankwidth
 	1,               // num_partitions
     }
 
@@ -138,7 +138,7 @@
         "MTD flash",                   // name
 	CONFIG_MTD_CSTM_MIPS_IXX_START,      // window_addr
 	CONFIG_MTD_CSTM_MIPS_IXX_LEN,        // window_size
-        CONFIG_MTD_CSTM_MIPS_IXX_BUSWIDTH,   // buswidth
+        CONFIG_MTD_CSTM_MIPS_IXX_BUSWIDTH,   // bankwidth
 	1,                             // num_partitions
     },
 
@@ -177,7 +177,7 @@
 	        }
 		cstm_mips_ixx_map[i].name = cstm_mips_ixx_board_desc[i].name;
 		cstm_mips_ixx_map[i].size = cstm_mips_ixx_board_desc[i].window_size;
-		cstm_mips_ixx_map[i].buswidth = cstm_mips_ixx_board_desc[i].buswidth;
+		cstm_mips_ixx_map[i].bankwidth = cstm_mips_ixx_board_desc[i].bankwidth;
 #if defined(CONFIG_MIPS_ITE8172) || defined(CONFIG_MIPS_IVR)
                 cstm_mips_ixx_map[i].set_vpp = cstm_mips_ixx_set_vpp;
 #endif

Index: db1x00-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/db1x00-flash.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- db1x00-flash.c	28 Aug 2003 06:50:24 -0000	1.1
+++ db1x00-flash.c	12 Jul 2004 21:59:43 -0000	1.2
@@ -30,7 +30,7 @@
 static unsigned long flash_size;
 
 static BCSR * const bcsr = (BCSR *)0xAE000000;
-static unsigned char flash_buswidth = 4;
+static unsigned char flash_bankwidth = 4;
 
 /* 
  * The Db1x boards support different flash densities. We setup
@@ -164,9 +164,9 @@
 			return 1;
 	}
 	db1xxx_mtd_map.size = window_size;
-	db1xxx_mtd_map.buswidth = flash_buswidth;
+	db1xxx_mtd_map.bankwidth = flash_bankwidth;
 	db1xxx_mtd_map.phys = window_addr;
-	db1xxx_mtd_map.buswidth = flash_buswidth;
+	db1xxx_mtd_map.bankwidth = flash_bankwidth;
 	return 0;
 }
 
@@ -189,7 +189,7 @@
 	 * specific machine settings might have been set above.
 	 */
 	printk(KERN_NOTICE "Db1xxx flash: probing %d-bit flash bus\n", 
-			db1xxx_mtd_map.buswidth*8);
+			db1xxx_mtd_map.bankwidth*8);
 	db1xxx_mtd_map.virt = (unsigned long)ioremap(window_addr, window_size);
 	db1xxx_mtd = do_map_probe("cfi_probe", &db1xxx_mtd_map);
 	if (!db1xxx_mtd) return -ENXIO;

Index: dbox2-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/dbox2-flash.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- dbox2-flash.c	26 May 2004 11:34:53 -0000	1.10
+++ dbox2-flash.c	12 Jul 2004 21:59:43 -0000	1.11
@@ -68,7 +68,7 @@
 struct map_info dbox2_flash_map = {
 	.name		= "D-Box 2 flash memory",
 	.size		= WINDOW_SIZE,
-	.buswidth	= 4,
+	.bankwidth	= 4,
 	.phys		= WINDOW_ADDR,
 };
 
@@ -87,7 +87,7 @@
 	mymtd = do_map_probe("cfi_probe", &dbox2_flash_map);
 	if (!mymtd) {
 	    // Probe for single Intel 28F640
-	    dbox2_flash_map.buswidth = 2;
+	    dbox2_flash_map.bankwidth = 2;
 	
 	    mymtd = do_map_probe("cfi_probe", &dbox2_flash_map);
 	}

Index: dc21285.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/dc21285.c,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -r1.18 -r1.19
--- dc21285.c	15 Apr 2004 23:04:38 -0000	1.18
+++ dc21285.c	12 Jul 2004 21:59:44 -0000	1.19
@@ -100,7 +100,7 @@
 
 void dc21285_copy_to(struct map_info *map, unsigned long to, const void *from, ssize_t len)
 {
-	switch (map->buswidth) {
+	switch (map->bankwidth) {
 		case 4:
 			while (len > 0) {
 				__u32 d = *((__u32*)from)++;
@@ -156,23 +156,23 @@
 	int nrparts;
 #endif
 
-	/* Determine buswidth */
+	/* Determine bankwidth */
 	switch (*CSR_SA110_CNTL & (3<<14)) {
 		case SA110_CNTL_ROMWIDTH_8: 
-			dc21285_map.buswidth = 1;
+			dc21285_map.bankwidth = 1;
 			break;
 		case SA110_CNTL_ROMWIDTH_16: 
-			dc21285_map.buswidth = 2; 
+			dc21285_map.bankwidth = 2; 
 			break;
 		case SA110_CNTL_ROMWIDTH_32: 
-			dc21285_map.buswidth = 4; 
+			dc21285_map.bankwidth = 4; 
 			break;
 		default:
-			printk (KERN_ERR "DC21285 flash: undefined buswidth\n");
+			printk (KERN_ERR "DC21285 flash: undefined bankwidth\n");
 			return -ENXIO;
 	}
-	printk (KERN_NOTICE "DC21285 flash support (%d-bit buswidth)\n",
-		dc21285_map.buswidth*8);
+	printk (KERN_NOTICE "DC21285 flash support (%d-bit bankwidth)\n",
+		dc21285_map.bankwidth*8);
 
 	/* Let's map the flash area */
 	dc21285_map.map_priv_1 = (unsigned long)ioremap(DC21285_FLASH, 16*1024*1024);

Index: dilnetpc.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/dilnetpc.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- dilnetpc.c	21 May 2003 12:45:18 -0000	1.12
+++ dilnetpc.c	12 Jul 2004 21:59:44 -0000	1.13
@@ -252,7 +252,7 @@
 static struct map_info dnpc_map = {
 	.name = "ADNP Flash Bank",
 	.size = ADNP_WINDOW_SIZE,
-	.buswidth = 1,
+	.bankwidth = 1,
 	.set_vpp = adnp_set_vpp,
 	.phys = WINDOW_ADDR
 };

Index: ebony.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/ebony.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- ebony.c	26 Apr 2004 12:35:36 -0000	1.9
+++ ebony.c	12 Jul 2004 21:59:44 -0000	1.10
@@ -30,13 +30,13 @@
 static struct map_info ebony_small_map = {
 	.name =		"Ebony small flash",
 	.size =		EBONY_SMALL_FLASH_SIZE,
-	.buswidth =	1,
+	.bankwidth =	1,
 };
 
 static struct map_info ebony_large_map = {
 	.name =		"Ebony large flash",
 	.size =		EBONY_LARGE_FLASH_SIZE,
-	.buswidth =	1,
+	.bankwidth =	1,
 };
 
 static struct mtd_partition ebony_small_partitions[] = {

Index: edb7312.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/edb7312.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- edb7312.c	23 Jun 2003 11:48:18 -0000	1.9
+++ edb7312.c	12 Jul 2004 21:59:44 -0000	1.10
@@ -39,7 +39,7 @@
 struct map_info edb7312nor_map = {
 	.name = "NOR flash on EDB7312",
 	.size = WINDOW_SIZE,
-	.buswidth = BUSWIDTH,
+	.bankwidth = BUSWIDTH,
 	.phys = WINDOW_ADDR,
 };
 

Index: elan-104nc.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/elan-104nc.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- elan-104nc.c	12 Jul 2004 14:28:52 -0000	1.19
+++ elan-104nc.c	12 Jul 2004 21:59:44 -0000	1.20
@@ -201,7 +201,7 @@
 	.size = 8*1024*1024, /* this must be set to a maximum possible amount
 			of flash so the cfi probe routines find all
 			the chips */
-	.buswidth = 2,
+	.bankwidth = 2,
 	.read8 = elan_104nc_read8,
 	.read16 = elan_104nc_read16,
 	.read32 = elan_104nc_read32,

Index: epxa10db-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/epxa10db-flash.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- epxa10db-flash.c	21 May 2003 12:45:18 -0000	1.10
+++ epxa10db-flash.c	12 Jul 2004 21:59:44 -0000	1.11
@@ -50,7 +50,7 @@
 static struct map_info epxa_map = {
 	.name =		"EPXA flash",
 	.size =		FLASH_SIZE,
-	.buswidth =	2,
+	.bankwidth =	2,
 	.phys =		FLASH_START,
 };
 

Index: fortunet.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/fortunet.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- fortunet.c	21 May 2003 12:45:18 -0000	1.6
+++ fortunet.c	12 Jul 2004 21:59:44 -0000	1.7
@@ -25,7 +25,7 @@
 struct map_region
 {
 	int			window_addr_physical;
-	int			altbuswidth;
+	int			altbankwidth;
 	struct map_info		map_info;
 	struct mtd_info		*mymtd;
 	struct mtd_partition	parts[MAX_NUM_PARTITIONS];
@@ -41,7 +41,7 @@
 
 struct map_info default_map = {
 	.size = DEF_WINDOW_SIZE,
-	.buswidth = 4,
+	.bankwidth = 4,
 };
 
 static char * __init get_string_option(char *dest,int dest_size,char *sor)
@@ -102,7 +102,7 @@
 	if(params[0]<1)
 	{
 		printk(MTD_FORTUNET_PK "Bad parameters for MTD Region "
-			" name,region-number[,base,size,buswidth,altbuswidth]\n");
+			" name,region-number[,base,size,bankwidth,altbankwidth]\n");
 		return 1;
 	}
 	if((params[1]<0)||(params[1]>=MAX_NUM_REGIONS))
@@ -116,7 +116,7 @@
 		&default_map,sizeof(map_regions[params[1]].map_info));
         map_regions_set[params[1]] = 1;
         map_regions[params[1]].window_addr_physical = DEF_WINDOW_ADDR_PHY;
-        map_regions[params[1]].altbuswidth = 2;
+        map_regions[params[1]].altbankwidth = 2;
         map_regions[params[1]].mymtd = NULL;
 	map_regions[params[1]].map_info.name = map_regions[params[1]].map_name;
 	strcpy(map_regions[params[1]].map_info.name,string);
@@ -130,11 +130,11 @@
 	}
 	if(params[0]>3)
 	{
-		map_regions[params[1]].map_info.buswidth = params[4];
+		map_regions[params[1]].map_info.bankwidth = params[4];
 	}
 	if(params[0]>4)
 	{
-		map_regions[params[1]].altbuswidth = params[5];
+		map_regions[params[1]].altbankwidth = params[5];
 	}
 	return 1;
 }
@@ -193,7 +193,7 @@
 				sizeof(map_regions[ix].map_info));
 			map_regions_set[ix] = 1;
 			map_regions[ix].window_addr_physical = DEF_WINDOW_ADDR_PHY;
-			map_regions[ix].altbuswidth = 2;
+			map_regions[ix].altbankwidth = 2;
 			map_regions[ix].mymtd = NULL;
 			map_regions[ix].map_info.name = map_regions[ix].map_name;
 			strcpy(map_regions[ix].map_info.name,"FORTUNET");
@@ -227,13 +227,13 @@
 			map_regions[ix].mymtd = do_map_probe("cfi_probe",
 				&map_regions[ix].map_info);
 			if((!map_regions[ix].mymtd)&&(
-				map_regions[ix].altbuswidth!=map_regions[ix].map_info.buswidth))
+				map_regions[ix].altbankwidth!=map_regions[ix].map_info.bankwidth))
 			{
-				printk(KERN_NOTICE MTD_FORTUNET_PK "Trying alternate buswidth "
+				printk(KERN_NOTICE MTD_FORTUNET_PK "Trying alternate bankwidth "
 					"for %s flash.\n",
 					map_regions[ix].map_info.name);
-				map_regions[ix].map_info.buswidth =
-					map_regions[ix].altbuswidth;
+				map_regions[ix].map_info.bankwidth =
+					map_regions[ix].altbankwidth;
 				map_regions[ix].mymtd = do_map_probe("cfi_probe",
 					&map_regions[ix].map_info);
 			}

Index: ichxrom.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/ichxrom.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- ichxrom.c	12 Jul 2004 14:33:25 -0000	1.2
+++ ichxrom.c	12 Jul 2004 21:59:44 -0000	1.3
@@ -105,7 +105,7 @@
 		.name = MOD_NAME,
 		.phys = NO_XIP,
 		.size = 0,
-		.buswidth = 1,
+		.bankwidth = 1,
 		.read8 = ichxrom_read8,
 		.read16 = ichxrom_read16,
 		.read32 = ichxrom_read32,

Index: impa7.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/impa7.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- impa7.c	23 Jun 2003 11:47:43 -0000	1.9
+++ impa7.c	12 Jul 2004 21:59:44 -0000	1.10
@@ -43,12 +43,12 @@
 	{
 		.name = "impA7 NOR Flash Bank #0",
 		.size = WINDOW_SIZE0,
-		.buswidth = BUSWIDTH,
+		.bankwidth = BUSWIDTH,
 	},
 	{
 		.name = "impA7 NOR Flash Bank #1",
 		.size = WINDOW_SIZE1,
-		.buswidth = BUSWIDTH,
+		.bankwidth = BUSWIDTH,
 	},
 };
 

Index: integrator-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/integrator-flash.c,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -r1.15 -r1.16
--- integrator-flash.c	27 Feb 2004 22:37:39 -0000	1.15
+++ integrator-flash.c	12 Jul 2004 21:59:44 -0000	1.16
@@ -108,7 +108,7 @@
 	 * look for CFI based flash parts fitted to this board
 	 */
 	info->map.size		= size;
-	info->map.buswidth	= plat->width;
+	info->map.bankwidth	= plat->width;
 	info->map.phys		= res->start;
 	info->map.virt		= (unsigned long) base;
 	info->map.name		= dev->dev.bus_id;

Index: integrator-flash-v24.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/integrator-flash-v24.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- integrator-flash-v24.c	11 Oct 2003 09:43:58 -0000	1.12
+++ integrator-flash-v24.c	12 Jul 2004 21:59:44 -0000	1.13
@@ -174,7 +174,7 @@
 	 * look for CFI based flash parts fitted to this board
 	 */
 	armflash_map.size       = size;
-	armflash_map.buswidth   = 4;
+	armflash_map.bankwidth   = 4;
 	armflash_map.virt = (unsigned long) base;
 
 	simple_map_init(&armflash_map);

Index: iq80310.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/iq80310.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- iq80310.c	23 Jun 2003 11:48:18 -0000	1.17
+++ iq80310.c	12 Jul 2004 21:59:44 -0000	1.18
@@ -31,7 +31,7 @@
 static struct map_info iq80310_map = {
 	.name = "IQ80310 flash",
 	.size = WINDOW_SIZE,
-	.buswidth = BUSWIDTH,
+	.bankwidth = BUSWIDTH,
 	.phys = WINDOW_ADDR
 };
 

Index: ixp4xx.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/ixp4xx.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ixp4xx.c	13 May 2004 22:21:26 -0000	1.1
+++ ixp4xx.c	12 Jul 2004 21:59:44 -0000	1.2
@@ -168,7 +168,7 @@
 	 * any board use 8-bit access, we'll fixup the driver to
 	 * handle that.
 	 */
-	info->map.buswidth = 2;
+	info->map.bankwidth = 2;
 	info->map.name = dev->dev.bus_id;
 	info->map.read16 = ixp4xx_read16,
 	info->map.write16 = ixp4xx_write16,

Index: l440gx.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/l440gx.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- l440gx.c	21 May 2003 12:45:19 -0000	1.12
+++ l440gx.c	12 Jul 2004 21:59:44 -0000	1.13
@@ -46,7 +46,7 @@
 struct map_info l440gx_map = {
 	.name = "L440GX BIOS",
 	.size = WINDOW_SIZE,
-	.buswidth = BUSWIDTH,
+	.bankwidth = BUSWIDTH,
 	.phys = WINDOW_ADDR,
 #if 0
 	/* FIXME verify that this is the 

Index: lasat.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/lasat.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- lasat.c	2 Sep 2003 16:36:40 -0000	1.6
+++ lasat.c	12 Jul 2004 21:59:44 -0000	1.7
@@ -37,7 +37,7 @@
 
 static struct map_info lasat_map = {
 	.name = "LASAT flash",
-	.buswidth = 4,
+	.bankwidth = 4,
 	.set_vpp = lasat_set_vpp
 };
 

Index: lubbock-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/lubbock-flash.c,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -r1.14 -r1.15
--- lubbock-flash.c	12 Jul 2004 14:33:56 -0000	1.14
+++ lubbock-flash.c	12 Jul 2004 21:59:44 -0000	1.15
@@ -71,7 +71,7 @@
 	int flashboot = (LUB_CONF_SWITCHES & 1);
 	int ret = 0, i;
 
-	lubbock_maps[0].buswidth = lubbock_maps[1].buswidth = 
+	lubbock_maps[0].bankwidth = lubbock_maps[1].bankwidth = 
 		(BOOT_DEF & 1) ? 2 : 4;
 
 	/* Compensate for the nROMBT switch which swaps the flash banks */
@@ -96,9 +96,9 @@
 			printk(KERN_WARNING "Failed to ioremap cached %s\n", lubbock_maps[i].name);
 		simple_map_init(&lubbock_maps[i]);
 
-		printk(KERN_NOTICE "Probing %s at physical address 0x%08lx (%d-bit buswidth)\n",
+		printk(KERN_NOTICE "Probing %s at physical address 0x%08lx (%d-bit bankwidth)\n",
 		       lubbock_maps[i].name, lubbock_maps[i].phys, 
-		       lubbock_maps[i].buswidth * 8);
+		       lubbock_maps[i].bankwidth * 8);
 
 		mymtds[i] = do_map_probe("cfi_probe", &lubbock_maps[i]);
 		

Index: mbx860.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/mbx860.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- mbx860.c	21 May 2003 12:45:19 -0000	1.5
+++ mbx860.c	12 Jul 2004 21:59:44 -0000	1.6
@@ -54,7 +54,7 @@
 	.name = "MBX flash",
 	.size = WINDOW_SIZE,
 	.phys = WINDOW_ADDR,
-	.buswidth = 4,
+	.bankwidth = 4,
 };
 
 int __init init_mbx(void)

Index: mpc1211.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/mpc1211.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- mpc1211.c	26 Oct 2003 21:27:42 -0000	1.1
+++ mpc1211.c	12 Jul 2004 21:59:44 -0000	1.2
@@ -21,7 +21,7 @@
 struct map_info mpc1211_flash_map = {
 	.name		= "MPC-1211 FLASH",
 	.size		= 0x80000,
-	.buswidth	= 1,
+	.bankwidth	= 1,
 };
 
 static struct mtd_partition mpc1211_partitions[] = {

Index: netsc520.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/netsc520.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- netsc520.c	21 May 2003 12:45:19 -0000	1.9
+++ netsc520.c	12 Jul 2004 21:59:44 -0000	1.10
@@ -84,7 +84,7 @@
 static struct map_info netsc520_map = {
 	.name = "netsc520 Flash Bank",
 	.size = WINDOW_SIZE,
-	.buswidth = 4,
+	.bankwidth = 4,
 	.phys = WINDOW_ADDR,
 };
 

Index: nettel.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/nettel.c,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- nettel.c	20 May 2003 20:59:30 -0000	1.4
+++ nettel.c	12 Jul 2004 21:59:44 -0000	1.5
@@ -65,7 +65,7 @@
 static struct map_info nettel_intel_map = {
 	.name = "SnapGear Intel",
 	.size = 0,
-	.buswidth = INTEL_BUSWIDTH,
+	.bankwidth = INTEL_BUSWIDTH,
 };
 
 static struct mtd_partition nettel_intel_partitions[] = {
@@ -103,7 +103,7 @@
 static struct map_info nettel_amd_map = {
 	.name = "SnapGear AMD",
 	.size = AMD_WINDOW_MAXSIZE,
-	.buswidth = AMD_BUSWIDTH,
+	.bankwidth = AMD_BUSWIDTH,
 };
 
 static struct mtd_partition nettel_amd_partitions[] = {

Index: ocelot.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/ocelot.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- ocelot.c	21 May 2003 12:45:19 -0000	1.12
+++ ocelot.c	12 Jul 2004 21:59:44 -0000	1.13
@@ -49,14 +49,14 @@
 struct map_info ocelot_flash_map = {
 	.name = "Ocelot boot flash",
 	.size = FLASH_WINDOW_SIZE,
-	.buswidth = FLASH_BUSWIDTH,
+	.bankwidth = FLASH_BUSWIDTH,
 	.phys = FLASH_WINDOW_ADDR,
 };
 
 struct map_info ocelot_nvram_map = {
 	.name = "Ocelot NVRAM",
 	.size = NVRAM_WINDOW_SIZE,
-	.buswidth = NVRAM_BUSWIDTH,
+	.bankwidth = NVRAM_BUSWIDTH,
 	.phys = NVRAM_WINDOW_ADDR,
 };
 

Index: octagon-5066.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/octagon-5066.c,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- octagon-5066.c	21 May 2003 15:15:07 -0000	1.24
+++ octagon-5066.c	12 Jul 2004 21:59:44 -0000	1.25
@@ -155,7 +155,7 @@
 		.name = "Octagon 5066 Socket",
 		.phys = NO_XIP,
 		.size = 512 * 1024,
-		.buswidth = 1,
+		.bankwidth = 1,
 		.read8 = oct5066_read8,
 		.read16 = oct5066_read16,
 		.read32 = oct5066_read32,
@@ -170,7 +170,7 @@
 		.name = "Octagon 5066 Internal Flash",
 		.phys = NO_XIP,
 		.size = 2 * 1024 * 1024,
-		.buswidth = 1,
+		.bankwidth = 1,
 		.read8 = oct5066_read8,
 		.read16 = oct5066_read16,
 		.read32 = oct5066_read32,

Index: omap-toto-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/omap-toto-flash.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- omap-toto-flash.c	21 Oct 2003 13:55:21 -0000	1.1
+++ omap-toto-flash.c	12 Jul 2004 21:59:44 -0000	1.2
@@ -34,7 +34,7 @@
 
 static struct map_info omap_toto_map_flash = {
 	.name =		"OMAP Toto flash",
-	.buswidth =	2,
+	.bankwidth =	2,
 	.virt =		OMAP_TOTO_FLASH_BASE,
 };
 
@@ -85,7 +85,7 @@
 	 * specific machine settings might have been set above.
 	 */
 	printk(KERN_NOTICE "OMAP toto flash: probing %d-bit flash bus\n",
-		omap_toto_map_flash.buswidth*8);
+		omap_toto_map_flash.bankwidth*8);
 	flash_mtd = do_map_probe("jedec_probe", &omap_toto_map_flash);
 	if (!flash_mtd)
 		return -ENXIO;

Index: pb1xxx-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/pb1xxx-flash.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- pb1xxx-flash.c	28 Aug 2003 06:50:24 -0000	1.10
+++ pb1xxx-flash.c	12 Jul 2004 21:59:44 -0000	1.11
@@ -125,7 +125,7 @@
 static struct map_info pb1xxx_mtd_map = {
 	.name		= NAME,
 	.size		= SIZE,
-	.buswidth	= BUSWIDTH,
+	.bankwidth	= BUSWIDTH,
 	.phys		= PADDR,
 };
 

Index: pci.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/pci.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- pci.c	12 Jul 2004 14:36:04 -0000	1.6
+++ pci.c	12 Jul 2004 21:59:44 -0000	1.7
@@ -48,7 +48,7 @@
 {
 	u32 win_base;
 
-	map->map.buswidth = 1;
+	map->map.bankwidth = 1;
 	map->map.size     = 0x00800000;
 	map->base         = ioremap_nocache(pci_resource_start(dev, 0),
 					    pci_resource_len(dev, 0));
@@ -147,7 +147,7 @@
 	if (!len || !base)
 		return -ENXIO;
 
-	map->map.buswidth = 4;
+	map->map.bankwidth = 4;
 	map->map.size     = len;
 	map->base         = ioremap_nocache(base, len);
 

Index: pcmciamtd.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/pcmciamtd.c,v
retrieving revision 1.49
retrieving revision 1.50
diff -u -r1.49 -r1.50
--- pcmciamtd.c	12 Jul 2004 14:36:58 -0000	1.49
+++ pcmciamtd.c	12 Jul 2004 21:59:44 -0000	1.50
@@ -73,7 +73,7 @@
 /* Module parameters */
 
 /* 2 = do 16-bit transfers, 1 = do 8-bit transfers */
-static int buswidth = 2;
+static int bankwidth = 2;
 
 /* Speed of memory accesses, in ns */
 static int mem_speed;
@@ -93,8 +93,8 @@
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Simon Evans <spse at secret.org.uk>");
 MODULE_DESCRIPTION(DRIVER_DESC);
-MODULE_PARM(buswidth, "i");
-MODULE_PARM_DESC(buswidth, "Set buswidth (1=8 bit, 2=16 bit, default=2)");
+MODULE_PARM(bankwidth, "i");
+MODULE_PARM_DESC(bankwidth, "Set bankwidth (1=8 bit, 2=16 bit, default=2)");
 MODULE_PARM(mem_speed, "i");
 MODULE_PARM_DESC(mem_speed, "Set memory access speed in ns");
 MODULE_PARM(force_size, "i");
@@ -439,9 +439,9 @@
 		case CISTPL_DEVICE_GEO: {
 			cistpl_device_geo_t *t = &parse.device_geo;
 			int i;
-			dev->pcmcia_map.buswidth = t->geo[0].buswidth;
+			dev->pcmcia_map.bankwidth = t->geo[0].bankwidth;
 			for(i = 0; i < t->ngeo; i++) {
-				DEBUG(2, "region: %d buswidth = %u", i, t->geo[i].buswidth);
+				DEBUG(2, "region: %d bankwidth = %u", i, t->geo[i].bankwidth);
 				DEBUG(2, "region: %d erase_block = %u", i, t->geo[i].erase_block);
 				DEBUG(2, "region: %d read_block = %u", i, t->geo[i].read_block);
 				DEBUG(2, "region: %d write_block = %u", i, t->geo[i].write_block);
@@ -460,17 +460,17 @@
 	if(!dev->pcmcia_map.size)
 		dev->pcmcia_map.size = MAX_PCMCIA_ADDR;
 
-	if(!dev->pcmcia_map.buswidth)
-		dev->pcmcia_map.buswidth = 2;
+	if(!dev->pcmcia_map.bankwidth)
+		dev->pcmcia_map.bankwidth = 2;
 
 	if(force_size) {
 		dev->pcmcia_map.size = force_size << 20;
 		DEBUG(2, "size forced to %dM", force_size);
 	}
 
-	if(buswidth) {
-		dev->pcmcia_map.buswidth = buswidth;
-		DEBUG(2, "buswidth forced to %d", buswidth);
+	if(bankwidth) {
+		dev->pcmcia_map.bankwidth = bankwidth;
+		DEBUG(2, "bankwidth forced to %d", bankwidth);
 	}		
 
 	dev->pcmcia_map.name = dev->mtd_name;
@@ -480,7 +480,7 @@
 	}
 
 	DEBUG(1, "Device: Size: %lu Width:%d Name: %s",
-	      dev->pcmcia_map.size, dev->pcmcia_map.buswidth << 3, dev->mtd_name);
+	      dev->pcmcia_map.size, dev->pcmcia_map.bankwidth << 3, dev->mtd_name);
 }
 
 
@@ -536,7 +536,7 @@
 	   whole card - otherwise we try smaller windows until we succeed */
 
 	req.Attributes =  WIN_MEMORY_TYPE_CM | WIN_ENABLE;
-	req.Attributes |= (dev->pcmcia_map.buswidth == 1) ? WIN_DATA_WIDTH_8 : WIN_DATA_WIDTH_16;
+	req.Attributes |= (dev->pcmcia_map.bankwidth == 1) ? WIN_DATA_WIDTH_8 : WIN_DATA_WIDTH_16;
 	req.Base = 0;
 	req.AccessSpeed = mem_speed;
 	link->win = (window_handle_t)link->handle;
@@ -828,9 +828,9 @@
 {
 	info(DRIVER_DESC " " DRIVER_VERSION);
 
-	if(buswidth && buswidth != 1 && buswidth != 2) {
-		info("bad buswidth (%d), using default", buswidth);
-		buswidth = 2;
+	if(bankwidth && bankwidth != 1 && bankwidth != 2) {
+		info("bad bankwidth (%d), using default", bankwidth);
+		bankwidth = 2;
 	}
 	if(force_size && (force_size < 1 || force_size > 64)) {
 		info("bad force_size (%d), using default", force_size);

Index: pnc2000.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/pnc2000.c,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -r1.14 -r1.15
--- pnc2000.c	21 May 2003 12:45:19 -0000	1.14
+++ pnc2000.c	12 Jul 2004 21:59:44 -0000	1.15
@@ -29,7 +29,7 @@
 struct map_info pnc_map = {
 	.name = "PNC-2000",
 	.size = WINDOW_SIZE,
-	.buswidth = 4,
+	.bankwidth = 4,
 	.phys = 0xFFFFFFFF,
 	.virt = WINDOW_ADDR,
 };

Index: redwood.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/redwood.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- redwood.c	21 Nov 2003 23:09:52 -0000	1.7
+++ redwood.c	12 Jul 2004 21:59:44 -0000	1.8
@@ -116,7 +116,7 @@
 struct map_info redwood_flash_map = {
 	.name = "IBM Redwood",
 	.size = WINDOW_SIZE,
-	.buswidth = 2,
+	.bankwidth = 2,
 	.phys = WINDOW_ADDR,
 };
 

Index: rpxlite.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/rpxlite.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- rpxlite.c	21 May 2003 12:45:19 -0000	1.19
+++ rpxlite.c	12 Jul 2004 21:59:44 -0000	1.20
@@ -21,7 +21,7 @@
 static struct map_info rpxlite_map = {
 	.name = "RPX",
 	.size = WINDOW_SIZE,
-	.buswidth = 4,
+	.bankwidth = 4,
 	.phys = WINDOW_ADDR,
 };
 

Index: sbc8240.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/sbc8240.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- sbc8240.c	30 Sep 2003 19:37:00 -0000	1.2
+++ sbc8240.c	12 Jul 2004 21:59:45 -0000	1.3
@@ -208,7 +208,7 @@
 	{
 		.name           = "sbc8240 Flash Bank #0",
 		.size           = WINDOW_SIZE0,
-		.buswidth       = BUSWIDTH0,
+		.bankwidth       = BUSWIDTH0,
 		.read8          = sbc8240_read8,
 		.read16         = sbc8240_read16,
 		.read32         = sbc8240_read32,
@@ -223,7 +223,7 @@
 	{
 		.name           = "sbc8240 Flash Bank #1",
 		.size           = WINDOW_SIZE1,
-		.buswidth       = BUSWIDTH1,
+		.bankwidth       = BUSWIDTH1,
 		.read8          = sbc8240_read8,
 		.read16         = sbc8240_read16,
 		.read32         = sbc8240_read32,

Index: sbc_gxx.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/sbc_gxx.c,v
retrieving revision 1.27
retrieving revision 1.28
diff -u -r1.27 -r1.28
--- sbc_gxx.c	12 Jul 2004 14:39:08 -0000	1.27
+++ sbc_gxx.c	12 Jul 2004 21:59:45 -0000	1.28
@@ -208,7 +208,7 @@
 	.size = MAX_SIZE_KiB*1024, /* this must be set to a maximum possible amount
 			 of flash so the cfi probe routines find all
 			 the chips */
-	.buswidth = 1,
+	.bankwidth = 1,
 	.read8 = sbc_gxx_read8,
 	.read16 = sbc_gxx_read16,
 	.read32 = sbc_gxx_read32,

Index: sc520cdp.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/sc520cdp.c,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -r1.15 -r1.16
--- sc520cdp.c	21 May 2003 12:45:20 -0000	1.15
+++ sc520cdp.c	12 Jul 2004 21:59:45 -0000	1.16
@@ -90,19 +90,19 @@
 	{
 		.name = "SC520CDP Flash Bank #0",
 		.size = WINDOW_SIZE_0,
-		.buswidth = 4,
+		.bankwidth = 4,
 		.phys = WINDOW_ADDR_0
 	},
 	{
 		.name = "SC520CDP Flash Bank #1",
 		.size = WINDOW_SIZE_1,
-		.buswidth = 4,
+		.bankwidth = 4,
 		.phys = WINDOW_ADDR_1
 	},
 	{
 		.name = "SC520CDP DIL Flash",
 		.size = WINDOW_SIZE_2,
-		.buswidth = 1,
+		.bankwidth = 1,
 		.phys = WINDOW_ADDR_2
 	},
 };

Index: scb2_flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/scb2_flash.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- scb2_flash.c	12 Jul 2004 14:40:58 -0000	1.7
+++ scb2_flash.c	12 Jul 2004 21:59:45 -0000	1.8
@@ -67,7 +67,7 @@
 struct map_info scb2_map = {
 	.name =      "SCB2 BIOS Flash",
 	.size =      0,
-	.buswidth =  1,
+	.bankwidth =  1,
 };
 static int region_fail;
 

Index: scx200_docflash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/scx200_docflash.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- scx200_docflash.c	21 May 2003 12:45:20 -0000	1.5
+++ scx200_docflash.c	12 Jul 2004 21:59:45 -0000	1.6
@@ -173,9 +173,9 @@
 
 	scx200_docflash_map.size = size;
 	if (width == 8)
-		scx200_docflash_map.buswidth = 1;
+		scx200_docflash_map.bankwidth = 1;
 	else
-		scx200_docflash_map.buswidth = 2;
+		scx200_docflash_map.bankwidth = 2;
 
 	simple_map_init(&scx200_docflash_map);
 

Index: solutionengine.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/solutionengine.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- solutionengine.c	12 Jul 2004 14:42:19 -0000	1.12
+++ solutionengine.c	12 Jul 2004 21:59:45 -0000	1.13
@@ -27,13 +27,13 @@
 struct map_info soleng_eprom_map = {
 	.name = "Solution Engine EPROM",
 	.size = 0x400000,
-	.buswidth = 4,
+	.bankwidth = 4,
 };
 
 struct map_info soleng_flash_map = {
 	.name = "Solution Engine FLASH",
 	.size = 0x400000,
-	.buswidth = 4,
+	.bankwidth = 4,
 };
 
 static const char *probes[] = { "RedBoot", "cmdlinepart", NULL };

Index: sun_uflash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/sun_uflash.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- sun_uflash.c	12 Jul 2004 14:45:36 -0000	1.8
+++ sun_uflash.c	12 Jul 2004 21:59:45 -0000	1.9
@@ -51,7 +51,7 @@
 struct map_info uflash_map_templ = {
 		.name =		"SUNW,???-????",
 		.size =		UFLASH_WINDOW_SIZE,
-		.buswidth =	UFLASH_BUSWIDTH,
+		.bankwidth =	UFLASH_BUSWIDTH,
 };
 
 int uflash_devinit(struct linux_ebus_device* edev)

Index: tqm8xxl.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/tqm8xxl.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- tqm8xxl.c	12 Jul 2004 14:47:07 -0000	1.10
+++ tqm8xxl.c	12 Jul 2004 21:59:45 -0000	1.11
@@ -151,7 +151,7 @@
 		sprintf(map_banks[idx]->name, "TQM8xxL%d", idx);
 
 		map_banks[idx]->size = flash_size;
-		map_banks[idx]->buswidth = 4;
+		map_banks[idx]->bankwidth = 4;
 
 		simple_map_init(map_banks[idx]);
 

Index: tsunami_flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/tsunami_flash.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- tsunami_flash.c	21 May 2003 15:15:08 -0000	1.6
+++ tsunami_flash.c	12 Jul 2004 21:59:45 -0000	1.7
@@ -61,7 +61,7 @@
 	.name = "flash chip on the Tsunami TIG bus",
 	.size = MAX_TIG_FLASH_SIZE,
 	.phys = NO_XIP;
-	.buswidth = 1,
+	.bankwidth = 1,
 	.read8 = tsunami_flash_read8,
 	.copy_from = tsunami_flash_copy_from,
 	.write8 = tsunami_flash_write8,

Index: uclinux.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/uclinux.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- uclinux.c	12 Jul 2004 14:48:48 -0000	1.6
+++ uclinux.c	12 Jul 2004 21:59:45 -0000	1.7
@@ -64,7 +64,7 @@
 	mapp = &uclinux_ram_map;
 	mapp->phys = (unsigned long) &_ebss;
 	mapp->size = PAGE_ALIGN(*((unsigned long *)((&_ebss) + 8)));
-	mapp->buswidth = 4;
+	mapp->bankwidth = 4;
 
 	printk("uclinux[mtd]: RAM probe address=0x%x size=0x%x\n",
 	       	(int) mapp->map_priv_2, (int) mapp->size);

Index: vmax301.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/vmax301.c,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -r1.28 -r1.29
--- vmax301.c	21 May 2003 15:15:08 -0000	1.28
+++ vmax301.c	12 Jul 2004 21:59:45 -0000	1.29
@@ -146,7 +146,7 @@
 		.name = "VMAX301 Internal Flash",
 		.phys = NO_XIP,
 		.size = 3*2*1024*1024,
-		.buswidth = 1,
+		.bankwidth = 1,
 		.read8 = vmax301_read8,
 		.read16 = vmax301_read16,
 		.read32 = vmax301_read32,
@@ -162,7 +162,7 @@
 		.name = "VMAX301 Socket",
 		.phys = NO_XIP,
 		.size = 0,
-		.buswidth = 1,
+		.bankwidth = 1,
 		.read8 = vmax301_read8,
 		.read16 = vmax301_read16,
 		.read32 = vmax301_read32,

Index: wr_sbc82xx_flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/wr_sbc82xx_flash.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- wr_sbc82xx_flash.c	7 Jun 2004 10:21:32 -0000	1.1
+++ wr_sbc82xx_flash.c	12 Jul 2004 21:59:45 -0000	1.2
@@ -74,15 +74,15 @@
 	}
 
 	/* Set parameters for the big flash chip (CS6 or CS0) */
-	sbc82xx_flash_map[bigflash].buswidth = 4;
+	sbc82xx_flash_map[bigflash].bankwidth = 4;
 	sbc82xx_flash_map[bigflash].size = 0x4000000;
 
 	/* Set parameters for the small flash chip (CS0 or CS6) */
-	sbc82xx_flash_map[!bigflash].buswidth = 1;
+	sbc82xx_flash_map[!bigflash].bankwidth = 1;
 	sbc82xx_flash_map[!bigflash].size = 0x200000;
 
 	/* Set parameters for the user flash chip (CS1) */
-	sbc82xx_flash_map[2].buswidth = 4;
+	sbc82xx_flash_map[2].bankwidth = 4;
 	sbc82xx_flash_map[2].size = 0x4000000;
 
 	sbc82xx_flash_map[0].phys = mc->memc_br0 & 0xffff8000;





More information about the linux-mtd-cvs mailing list
Index: db1550-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/db1550-flash.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- db1550-flash.c	12 Apr 2004 06:38:39 -0000	1.1
+++ db1550-flash.c	12 Jul 2004 21:59:43 -0000	1.2
@@ -33,7 +33,7 @@
 	.name =	"Db1550 flash",
 };
 
-static unsigned char flash_buswidth = 4;
+static unsigned char flash_bankwidth = 4;
 
 /* 
  * Support only 64MB NOR Flash parts
@@ -141,8 +141,8 @@
 	struct mtd_partition *parts;
 	int nb_parts = 0;
 	
-	/* Default flash buswidth */
-	db1550_map.buswidth = flash_buswidth;
+	/* Default flash bankwidth */
+	db1550_map.bankwidth = flash_bankwidth;
 
 	if (setup_flash_params()) 
 		return -ENXIO;
@@ -159,7 +159,7 @@
 	 * specific machine settings might have been set above.
 	 */
 	printk(KERN_NOTICE "Pb1550 flash: probing %d-bit flash bus\n", 
-			db1550_map.buswidth*8);
+			db1550_map.bankwidth*8);
 	db1550_map.virt = 
 		(unsigned long)ioremap(window_addr, window_size);
 	mymtd = do_map_probe("cfi_probe", &db1550_map);

Index: h720x-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/h720x-flash.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- h720x-flash.c	28 May 2003 12:40:38 -0000	1.7
+++ h720x-flash.c	12 Jul 2004 21:59:44 -0000	1.8
@@ -24,7 +24,7 @@
 
 static struct map_info h720x_map = {
 	.name =		"H720X",
-	.buswidth =	4,
+	.bankwidth =	4,
 	.size =		FLASH_SIZE,
 	.phys =		FLASH_PHYS,
 };
@@ -80,13 +80,13 @@
 
 	simple_map_init(&h720x_map);
 
 	// Probe for flash buswidth 4
 	printk (KERN_INFO "H720x-MTD probing 32bit FLASH\n");
 	mymtd = do_map_probe("cfi_probe", &h720x_map);
 	if (!mymtd) {
 		printk (KERN_INFO "H720x-MTD probing 16bit FLASH\n");
-	    // Probe for buswidth 2
-	    h720x_map.buswidth = 2;
+	    // Probe for bankwidth 2
+	    h720x_map.bankwidth = 2;
 	    mymtd = do_map_probe("cfi_probe", &h720x_map);
 	}
 	    
@@ -80,13 +80,13 @@
 	simple_map_init(&h720x_map);
 
-	// Probe for flash buswidth 4
+	// Probe for flash bankwidth 4
 	printk (KERN_INFO "H720x-MTD probing 32bit FLASH\n");
 	mymtd = do_map_probe("cfi_probe", &h720x_map);

Index: pb1550-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/pb1550-flash.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- pb1550-flash.c	4 Mar 2004 06:45:51 -0000	1.2
+++ pb1550-flash.c	12 Jul 2004 21:59:44 -0000	1.3
@@ -34,7 +34,7 @@
 	.name =	"Pb1550 flash",
 };
 
-static unsigned char flash_buswidth = 4;
+static unsigned char flash_bankwidth = 4;
 
 /* 
  * Support only 64MB NOR Flash parts
@@ -157,8 +157,8 @@
 	struct mtd_partition *parts;
 	int nb_parts = 0;
 	
-	/* Default flash buswidth */
-	pb1550_map.buswidth = flash_buswidth;
+	/* Default flash bankwidth */
+	pb1550_map.bankwidth = flash_bankwidth;
 
 	if (setup_flash_params()) 
 		return -ENXIO;
@@ -175,7 +175,7 @@
 	 * specific machine settings might have been set above.
 	 */
 	printk(KERN_NOTICE "Pb1550 flash: probing %d-bit flash bus\n", 
-			pb1550_map.buswidth*8);
+			pb1550_map.bankwidth*8);
 	pb1550_map.virt = 
 		(unsigned long)ioremap(window_addr, window_size);
 	mymtd = do_map_probe("cfi_probe", &pb1550_map);

Index: sa1100-flash.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/sa1100-flash.c,v
retrieving revision 1.38
retrieving revision 1.39
diff -u -r1.38 -r1.39
--- sa1100-flash.c	22 Jan 2004 19:11:08 -0000	1.38
+++ sa1100-flash.c	12 Jul 2004 21:59:44 -0000	1.39
@@ -935,7 +935,7 @@
 		sa[i].map->virt = (unsigned long)sa[i].vbase;
 		sa[i].map->phys = sa[i].base;
 		sa[i].map->set_vpp = sa[i].set_vpp;
-		sa[i].map->buswidth = sa[i].width;
+		sa[i].map->bankwidth = sa[i].width;
 		sa[i].map->size = sa[i].size;
 
 		simple_map_init(sa[i].map);
@@ -1066,7 +1066,7 @@
 		return;
 	}
 
-	sa1100_probe_map.buswidth = msc & MSC_RBW ? 2 : 4;
+	sa1100_probe_map.bankwidth = msc & MSC_RBW ? 2 : 4;
 	sa1100_probe_map.size = SZ_1M;
 	sa1100_probe_map.phys = phys;
 	sa1100_probe_map.virt = (unsigned long)ioremap(phys, SZ_1M);
@@ -1253,7 +1253,7 @@
 		return nr;
 
 	/*
 	 * Retrieve the buswidth from the MSC registers.
 	 * We currently only implement CS0 and CS1 here.
 	 */
 	for (i = 0; i < nr; i++) {
@@ -1253,7 +1253,7 @@
 
 	/*
-	 * Retrieve the buswidth from the MSC registers.
+	 * Retrieve the bankwidth from the MSC registers.
 	 * We currently only implement CS0 and CS1 here.
 	 */
